#
# spec file for package hobbits
#
# Copyright (c) 2021-2024, Martin Hauke <mardnh@gmx.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define pffft_hash 7c3b5a7

Name:           hobbits
Version:        0.54.1
Release:        1.3
Summary:        A GUI for bit-based analysis, processing, and visualization
License:        MIT
URL:            https://github.com/Mahlet-Inc/hobbits
Source:         https://github.com/Mahlet-Inc/hobbits/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
Source1:        https://bitbucket.org/jpommier/pffft/get/%{pffft_hash}.zip#/pffft-%{pffft_hash}.zip
Patch0:         hobbits-dont-hardcode-python3-version.patch
BuildRequires:  cmake
BuildRequires:  gcc-c++
BuildRequires:  libpcap-devel
BuildRequires:  pkgconfig
BuildRequires:  fdupes
BuildRequires:  python3-devel
BuildRequires:  pkgconfig(Qt5Concurrent)
BuildRequires:  pkgconfig(Qt5Core)
BuildRequires:  pkgconfig(Qt5Network)
BuildRequires:  pkgconfig(Qt5Widgets)
BuildRequires:  pkgconfig(libusb-1.0)
BuildRequires:  unzip
BuildRequires:  hicolor-icon-theme
Provides:       bundled(pffft)

%description
A GUI for bit-based analysis, processing, and visualization.

%package devel
Summary:        Development files for hobbits
Group:          Development/Libraries/C and C++
Requires:       %{name} = %{version}

%description devel
A GUI for bit-based analysis, processing, and visualization.

This subpackage contains files for developing applications thatwant to make use of hobbits.

%prep
%setup -q
%autopatch -p1

# 3rd party
cd external/pffft/
unzip -j %{SOURCE1}

%build
%cmake -DCMAKE_SKIP_RPATH:BOOL=OFF
%make_build

%install
%cmake_install

%files
%license LICENSE.txt
%doc CHANGELOG.md README.md
%{_bindir}/hobbits
%{_bindir}/hobbits-runner
%dir %{_libdir}/hobbits
%dir %{_libdir}/hobbits/plugins
%{_libdir}/hobbits/plugins/analyzers/
%{_libdir}/hobbits/plugins/analyzers/
%{_libdir}/hobbits/plugins/displays/
%{_libdir}/hobbits/plugins/importerexporters/
%{_libdir}/hobbits/plugins/operators/
%{_libdir}/libhobbits-core.so
%{_libdir}/libhobbits-python.so
%{_libdir}/libhobbits-widgets.so
%{_datadir}/applications/Hobbits.desktop
# FIXME: icons too large
%dir %{_datadir}/icons/hicolor/624x624/
%dir %{_datadir}/icons/hicolor/624x624/apps/
%{_datadir}/icons/hicolor/624x624/apps/HobbitsRingSmall.png

%files devel
%{_includedir}/hobbits/

%changelog
* Tue Apr 30 2024 Martin Hauke <mardnh@gmx.de>
- Update to version 0.54.1
  * add versionless Qt build compatibility.
* Fri Feb 17 2023 Martin Hauke <mardnh@gmx.de>
- Update to version 0.54.0
  Features
  * add Edit plugin.
* Sat Jun 18 2022 Martin Hauke <mardnh@gmx.de>
- Update to version 0.53.2
  Bug Fixes
  * correctly display kaitai value instances for #145
  * fix kaitai plugin byte and string array sizes.
* Sat Nov 27 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 0.53.0
  Features
  * add built-in batches.
  * add config setting for skipping delete confirmation.
  * replace FFTW with PFFFT and improve FFT UI and error reporting
* Thu Oct  7 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 0.52.0
  Bug Fixes
  * code quality improvements.
  * reimplementing the libusb-1.0 into the include statement.
  * removing trouble causing lines in USBreader.
  * resolve parser class names for kaitai specs with underscores.
  Features
  * add USB reader importer plugin.
  * UI for USB reader plugin is almost done.
  * USB reader plugin, device, interface, alternate setting, and
    endpoint selectors.
* Tue Aug 24 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 0.51.1
  Bug fixes
  * correctly reload custom kaitai KSY after it is edited
  * show type for array, byte, and string in kaitai display
* Sun Aug 22 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 0.50.0
  Bug Fixes
  * [core] BitArray fromString parsing error reports.
  * improve kaitai parser parser.
  Features
  * big fixes and improvements to kaitai
- Update patch:
  * hobbits-dont-hardcode-python3-version.patch
* Mon Jun  7 2021 Martin Hauke <mardnh@gmx.de>
- Add patch:
  * hobbits-dont-hardcode-python3-version.patch
* Sun Jun  6 2021 Jan Engelhardt <jengelh@inai.de>
- Remove useless ldconfig calls: there are libs with SONAME links.
* Fri Jun  4 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 0.50.0
  Features
  * better file dialog behavior during and between runs.
- Update to version 0.49.0
  Bug Fixes
  * [plugin] re-enable autocorrelation in Width Framer.
  Features
  * add Bit Container import/export plugin.
* Sat May 22 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 0.48.1
  Bug Fixes
  * release artifact paths.
- Update to version 0.48.0
  Bug Fixes
  * [plugin] json error parsing for kaitai compilers.
  * correctly load config in standalone builds.
  * correctly register Range and RangeHighlight meta types.
  * correctly resize BitArrays when setBytes is called.
  * prevent potential QFutureWatcher race conditions.
  Features
  * add basic "What's This?" help for plugin widgets.
  * arbitrary view splitting and full view persistence for.
* Thu May 13 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 0.47.0
  * improve plugin parameter specification (helps #84) (cef1055)
* Mon Apr 26 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 0.46.8
  * handle bad display parameters without crashing #99 (7c3c587)
* Sat Apr 24 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 0.46.7
  * appropriately offset imported sub-sections in kaitai (#93)
    (03067d4)
* Sat Apr 24 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 0.46.6
  * rollback offset changes in kaitai struct plugin (e2ac3c3)
* Fri Apr 23 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 0.46.5
  * actually synchronize parameter editor preview calls
  * track section offsets in kaitai parsing for #93 (ccd01f3)
* Tue Apr 13 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 0.46.3
  * swapped mac and windows binary releases.
* Fri Mar 19 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 0.46.3
  * correctly enforce FFTW thread-safety.
  * load python plugins correctly.
* Sun Feb  7 2021 Martin Hauke <mardnh@gmx.de>
- Initial package, version 0.46.2
